[CMF-checkins] CVS: Products/CMFCore - CMFCatalogAware.py:1.20
Grégoire Weber
zope.org at incept.ch
Mon Jul 19 08:02:32 EDT 2004
Update of /cvs-repository/Products/CMFCore
In directory cvs.zope.org:/tmp/cvs-serv32046
Modified Files:
CMFCatalogAware.py
Log Message:
- changed name of 'ICallableOpaqueItemWithHooks' to 'ICallableOpaqueItem'.
- added 'ICallableOpaqueItemEvents'.
- changed implementation and test accordingly.
=== Products/CMFCore/CMFCatalogAware.py 1.19 => 1.20 ===
--- Products/CMFCore/CMFCatalogAware.py:1.19 Wed Jun 30 11:49:39 2004
+++ Products/CMFCore/CMFCatalogAware.py Mon Jul 19 08:02:01 2004
@@ -27,7 +27,7 @@
from utils import _dtmldir
from utils import getToolByName
-from interfaces.IOpaqueItems import ICallableOpaqueItemWithHooks
+from interfaces.IOpaqueItems import ICallableOpaqueItem
class CMFCatalogAware(Base):
"""Mix-in for notifying portal_catalog and portal_workflow
@@ -122,8 +122,7 @@
# Call 'talkback' knowing that it is an opaque item.
# This will remain here as long as the discussion item does
# not implement ICallableOpaqueItemWithHooks (backwards
# compatibility).
if hasattr(aq_base(self), 'talkback'):
talkback = self.talkback
if talkback is not None:
@@ -132,11 +131,11 @@
# Other opaque items than 'talkback' may have callable
# manage_after* and manage_before* hooks.
# Loop over all attributes and add those to 'items'
- # implementing 'ICallableOpaqueItemWithHooks'.
+ # implementing 'ICallableOpaqueItem'.
self_base = aq_base(self)
for name in self_base.__dict__.keys():
obj = getattr(self_base, name)
- if ICallableOpaqueItemWithHooks.isImplementedBy(obj):
+ if ICallableOpaqueItem.isImplementedBy(obj):
items.append((obj.getId(), obj))
return tuple(items)
More information about the CMF-checkins
@@ -122,8 +122,7 @@
# Call 'talkback' knowing that it is an opaque item.
# This will remain here as long as the discussion item does
- # not implement ICallableOpaqueItemWithHooks (backwards
- # compatibility).
+ # not implement ICallableOpaqueItem (backwards compatibility).
if hasattr(aq_base(self), 'talkback'):
talkback = self.talkback
mailing list